*******************
Enumeration Classes
*******************

.. module:: yangson.enumerations
   :synopsis: Enumeration classes

.. autoclass:: ContentType
   :members:

.. autoclass:: NodeStatus
   :members:

.. autoclass:: ValidationScope
   :members:

.. autoclass:: DefaultDeny
   :members:

.. autoclass:: Axis
   :members:

.. autoclass:: MultiplicativeOp
   :members:

.. _7.21.2: https://www.rfc-editor.org/rfc/rfc7950.html#section-7.21.2
